<?php
/*
Plugin Name: WP Pro Poll System
Plugin URI: http://www.wpplugins.be/wp-pro-poll-system/
Description: Plugin to create polls on your website.
Author: پرشین اسکریپت
Version: 1.0.5
Author URI: http://www.persianscript.ir/
*/

//Plugin Path
$wp_poll_path = WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__));
$wp_poll_abs_path = ABSPATH. 'wp-content/plugins/' .str_replace(basename( __FILE__),"",plugin_basename(__FILE__));
$wp_poll_role_admin = 'add_users';
$wp_poll_plugin_slug = basename(dirname(__FILE__));


// Custom Tables
if(!class_exists('WP_List_Table')){
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}
require_once('includes/tables/pro_poll.php');
require_once('includes/wgt_functions.php');
require_once('includes/ajax_functions.php');


// Load jQuery into the theme
function wp_pro_poll_init_method() 
{
    global $wp_poll_path;
	wp_enqueue_script('jquery');
	
	// Load stylesheets
	wp_enqueue_style("wp_pro_poll_style", $wp_poll_path."templates/css/style.css", false, "2.0", "all");
	
	load_plugin_textdomain('wppropoll', false, basename( dirname( __FILE__ ) ) . '/localization' );
}    
add_action('init', 'wp_pro_poll_init_method');


// Load custom CSS
function wp_pro_poll_head_method() 
{
	global $wpdb;
	$set = $wpdb->get_results("SELECT * FROM ".$wpdb->prefix."pro_poll_settings LIMIT 1");
		
	if( !empty( $set[0]->custom_css ))
	{
		echo '<style type="text/css">'.$set[0]->custom_css.'</style>';
	}
}
add_action('wp_head', 'wp_pro_poll_head_method');


// Button to admin page
function wp_pro_poll_admin_actions() 
{
	global $wp_poll_role_admin, $wp_poll_path, $wp_version;
	
	
	if(is_admin() && isset($_GET['page']))
	{
		if( $_GET['page'] == 'wp-pro-poll' || $_GET['page'] == 'wp-new-pro-poll' || $_GET['page'] == 'wp-pro-poll-main-settings' )
		{
			// Load jQuery
			wp_enqueue_script('jquery');
			wp_enqueue_script('jquery-ui-core');
			
			if ( $wp_version >= 3.5 )
			{
				wp_enqueue_script( 'wp-color-picker');
				wp_enqueue_style( 'wp-color-picker' );
			}
			else
			{
				wp_enqueue_style( 'farbtastic' );
        		wp_enqueue_script( 'farbtastic' );
			}
		}
	}
	
	// Create menu
	if (function_exists('add_object_page')) 
	{
		add_object_page(__('Pro Polls','wppropoll'), __('Pro Poll','wppropoll'), $wp_poll_role_admin, "wp-pro-poll" , "wp_pro_poll", $wp_poll_path."images/polls-icon_16.png");
	}
	else
	{
		add_menu_page(__('Pro Polls','wppropoll'), __('Pro Poll','wppropoll'), $wp_poll_role_admin,  "wp-pro-poll" , "wp_pro_poll");
	}
	
	add_submenu_page("wp-pro-poll", __('Pro Polls','wppropoll'), __('Pro Polls','wppropoll'), $wp_poll_role_admin, "wp-pro-poll", "wp_pro_poll");
	add_submenu_page("wp-pro-poll", __('Add New Poll','wppropoll'), __('Add New Poll','wppropoll'), $wp_poll_role_admin, "wp-new-pro-poll", "wp_new_pro_poll");
	add_submenu_page("wp-pro-poll", __('Main Settings','wppropoll'), __('Main Settings','wppropoll'), $wp_poll_role_admin, "wp-pro-poll-main-settings", "wp_pro_poll_main_settings");
}
add_action('admin_menu', 'wp_pro_poll_admin_actions');


// MENU FUNCTIONS
function wp_pro_poll()
{
	include('templates/pro_poll.php');
}
function wp_new_pro_poll()
{
	include('templates/new_pro_poll.php');
}
function wp_pro_poll_main_settings()
{
	include('templates/pro_poll_main_settings.php');
}



// Create Database
function create_pro_poll_db_tables()
{
	global $wpdb, $wp_poll_abs_path;
	require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
	
	$table_poll = $wpdb->prefix . "pro_poll";
	$table_poll_options = $wpdb->prefix . "pro_poll_options";
	$table_poll_votes = $wpdb->prefix . "pro_poll_votes";
	$table_poll_settings = $wpdb->prefix . "pro_poll_settings";
   
    $sql_poll = "CREATE TABLE " . $table_poll . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    title varchar(200) NOT NULL,
		login_to_vote int(3) NOT NULL,
		limit_vote_by varchar(50) NOT NULL,
		limit_vote_nr int(10) NOT NULL,
		progress_color varchar(50) NOT NULL,
		progress_bg_color varchar(50) NOT NULL,
		poll_bg_color varchar(50) NOT NULL,
		title_color varchar(50) NOT NULL,
		option_color varchar(50) NOT NULL,
		vote_txt_color varchar(50) NOT NULL,
		show_percentage int(3) NOT NULL,
		show_am_votes int(3) NOT NULL,
		show_results int(3) NOT NULL,
		show_results_after_voting int(3) NOT NULL,
		poll_status int(3) NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	$sql_poll_options = "CREATE TABLE " . $table_poll_options . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    pid mediumint(9) NOT NULL,
		options varchar(200) NOT NULL,
		options_nr int(10) NOT NULL,
		votes int(10) NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	$sql_poll_votes = "CREATE TABLE " . $table_poll_votes . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    pid mediumint(9) NOT NULL,
		oid mediumint(9) NOT NULL,
		uid mediumint(9) NOT NULL,
		ip_address varchar(200) NOT NULL,
		time varchar(200) NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	$sql_poll_settings = "CREATE TABLE " . $table_poll_settings . " (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
	    custom_css text NOT NULL,
		default_color varchar(200) NOT NULL,
	    UNIQUE KEY id (id)
	);";
	
	if( $wpdb->get_var("show tables like '".$table_poll_settings."'") != $table_poll_settings )
	{
		dbDelta($sql_poll);
		dbDelta($sql_poll_options);
		dbDelta($sql_poll_votes);
		dbDelta($sql_poll_settings);
		
		$results = $wpdb->query( "INSERT INTO ".$table_poll_settings." 
			SET 
				custom_css = '', 
				default_color = '#9F0'
		");
	}
	else
	{
		dbDelta($sql_poll);
		dbDelta($sql_poll_options);
		dbDelta($sql_poll_votes);
		dbDelta($sql_poll_settings);
	}
}
add_action('admin_head', 'create_pro_poll_db_tables');



/*
 * Shortcodes
*/
//[pro_poll id=0]
function pro_poll_shortcode_heats( $atts, $content = null ) 
{
   	extract( shortcode_atts( array(
		'id'          => 1,
		'width'       => '',
		'vote_button' => '',
    ), $atts ) );
	
	ob_start();
	$res = pro_poll_wgt( $id, $width, $vote_button );
	$res = ob_get_clean();
	return $res;
}
add_shortcode('pro_poll', 'pro_poll_shortcode_heats');



/*
 * Widgets
*/
class pro_poll_side_widget extends WP_Widget {
	
	function pro_poll_side_widget() {
		$widget_ops = array('classname' => 'pro_poll_side_widget', 'description' => __( 'Pro Poll - Show your polls created with the WP Pro Poll System.') );
		$this->WP_Widget('pro_poll_side_widget', __('Pro Poll System - Show Poll.'), $widget_ops);
	}
	
	function widget( $args, $instance ) {
		
		extract($args);
		echo $before_widget;
			pro_poll_wgt( $instance['poll'], $instance['width'], $instance['vote_button'] );
		echo $after_widget;
	}
	
	
	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['poll'] = strip_tags($new_instance['poll']);
		$instance['width'] = $new_instance['width'];
		$instance['vote_button'] = $new_instance['vote_button'];
		
		return $instance;
	}
	
	
	function form( $instance ) {
		global $wpdb;
		
		//Defaults
		$instance = wp_parse_args( (array) $instance, array( 'poll' => ''));
		$instance = wp_parse_args( (array) $instance, array( 'width' => ''));
		$instance = wp_parse_args( (array) $instance, array( 'vote_button' => 'left'));
		
		// Load all available polls
		$polls = $wpdb->get_results("SELECT * FROM ".$wpdb->prefix."pro_poll ORDER BY id DESC");
		?>
        <p>
  			<label for="<?php echo $this->get_field_id('poll'); ?>"><?php _e('Select a poll:'); ?></label> <br />
            <select type="text" id="<?php echo $this->get_field_id( 'poll' ); ?>" name="<?php echo $this->get_field_name( 'poll' ); ?>">
            	<?php
				foreach( $polls as $poll )
				{
					?>	
            		<option value="<?php echo $poll->id; ?>" <?php echo $instance['poll'] == $poll->id ? 'selected="selected"' : '' ; ?>><?php echo $poll->title; ?></option>
                    <?php
				}
				?>
            </select>
		</p>
        
        <h4><?php _e('Optional CSS settings', 'wppropoll'); ?>:</h4>
        <p>
  			<label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Width (optional):'); ?></label> <br />
            <input type="text" name="<?php echo $this->get_field_name( 'width' ); ?>" value="<?php echo $instance['width']; ?>" />px.
		</p>
        <p>
  			<label for="<?php echo $this->get_field_id('vote_button'); ?>"><?php _e('Vote button position (optional):'); ?></label> <br />
            <select name="<?php echo $this->get_field_name( 'vote_button' ); ?>" style="width:170px;">
            	<option value="left" <?php echo empty( $instance['vote_button'] ) || $instance['vote_button'] == 'left' ? 'selected="selected"' : ''; ?>><?php _e('Left', 'wppropoll'); ?></option>
                <option value="right" <?php echo $instance['vote_button'] == 'right' ? 'selected="selected"' : ''; ?>><?php _e('Right', 'wppropoll'); ?></option>
            </select>
		</p>
		<?php
	}

}
function pro_poll_side_widget_init() {
	register_widget('pro_poll_side_widget');
}

add_action('widgets_init', 'pro_poll_side_widget_init');




/*
 * Custom Plugin Updater
*/
include_once( 'class-pro-poll-system-updater.php' );
$pro_ads_updater = new Pro_Poll_System_Updater( 'http://www.wpplugins.be/updates/wp_pro_poll/api/', __FILE__, array( 'licence_key' => get_option( 'mdp_update_access_key' ) ) );
?>